summaryrefslogtreecommitdiffstats
path: root/chalk/ui/squeezedcombobox.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /chalk/ui/squeezedcombobox.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'chalk/ui/squeezedcombobox.h')
-rw-r--r--chalk/ui/squeezedcombobox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/ui/squeezedcombobox.h b/chalk/ui/squeezedcombobox.h
index 50f4bc77..03a1cdb9 100644
--- a/chalk/ui/squeezedcombobox.h
+++ b/chalk/ui/squeezedcombobox.h
@@ -117,9 +117,9 @@ public:
TQString itemHighlighted( );
/**
* Sets the sizeHint() of this widget.
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
private slots:
void slotTimeOut();
@@ -117,9 +117,9 @@ public:
TQString itemHighlighted( );
/**
- * Sets the sizeHint() of this widget.
+ * Sets the tqsizeHint() of this widget.
*/